aboutsummaryrefslogtreecommitdiffstats
path: root/src/decoder/FlacInput.hxx
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2013-10-23 22:08:59 +0200
committerMax Kellermann <max@duempel.org>2013-10-23 23:12:02 +0200
commit93deb844996120b6326345d6d87e803142dd1968 (patch)
treed6c00669efffad1b15fc45e03158d6838a7e5827 /src/decoder/FlacInput.hxx
parentc4d4011c63808a64ca20a4b03fd455a83c23cc33 (diff)
downloadmpd-93deb844996120b6326345d6d87e803142dd1968.tar.gz
mpd-93deb844996120b6326345d6d87e803142dd1968.tar.xz
mpd-93deb844996120b6326345d6d87e803142dd1968.zip
input_stream: rename struct to InputStream
Diffstat (limited to 'src/decoder/FlacInput.hxx')
-rw-r--r--src/decoder/FlacInput.hxx7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/decoder/FlacInput.hxx b/src/decoder/FlacInput.hxx
index 2879f5dd4..ac2b4bd25 100644
--- a/src/decoder/FlacInput.hxx
+++ b/src/decoder/FlacInput.hxx
@@ -23,18 +23,19 @@
#include <FLAC/stream_decoder.h>
struct Decoder;
+struct InputStream;
/**
* This class wraps an #input_stream in libFLAC stream decoder
* callbacks.
*/
class FlacInput {
Decoder *const decoder;
- struct input_stream *input_stream;
+ InputStream &input_stream;
public:
- FlacInput(struct input_stream *_input_stream,
+ FlacInput(InputStream &_input_stream,
Decoder *_decoder=nullptr)
:decoder(_decoder), input_stream(_input_stream) {}
@@ -23,18 +23,19 @@
/**
- * This class wraps an #input_stream in libFLAC stream decoder
+ * This class wraps an #InputStream in libFLAC stream decoder
* callbacks.
*/